import { HttpClient, HttpHeaders, HttpResponse, HttpEvent, HttpParameterCodec, HttpContext } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FileInfo } from '../model/fileInfo';
import { FilePayload } from '../model/filePayload';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class FilesService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    encoder: HttpParameterCodec;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    private addToHttpParams;
    private addToHttpParamsRecursive;
    /**
     * Delete File
     * Permanently deletes the file from your Account. Required Access Level: ModifyFiles
     * @param name Name of your file including extension.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    filesByNameDelete(name: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
        context?: HttpContext;
    }): Observable<any>;
    filesByNameDelete(name: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
        context?: HttpContext;
    }): Observable<HttpResponse<any>>;
    filesByNameDelete(name: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
        context?: HttpContext;
    }): Observable<HttpEvent<any>>;
    /**
     * Download File
     * Gets content of the specified File. Required Access Level: ViewFiles
     * @param name Name of your file including extension.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    filesByNameGet(name: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/_*';
        context?: HttpContext;
    }): Observable<Blob>;
    filesByNameGet(name: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/_*';
        context?: HttpContext;
    }): Observable<HttpResponse<Blob>>;
    filesByNameGet(name: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/_*';
        context?: HttpContext;
    }): Observable<HttpEvent<Blob>>;
    /**
     * Load File Details
     * Returns the specified File\&#39;s details. Required Access Level: ViewFiles
     * @param name Name of your file including extension.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    filesByNameInfoGet(name: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<FileInfo>;
    filesByNameInfoGet(name: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<FileInfo>>;
    filesByNameInfoGet(name: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<FileInfo>>;
    /**
     * List Files
     * Returns a list of all your available files. Required Access Level: ViewFiles
     * @param limit Maximum number of returned items.
     * @param offset How many items should be returned ahead.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    filesGet(limit?: number, offset?: number, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<Array<FileInfo>>;
    filesGet(limit?: number, offset?: number, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<Array<FileInfo>>>;
    filesGet(limit?: number, offset?: number, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<Array<FileInfo>>>;
    /**
     * Upload File
     * Uploads selected file to the server. Required Access Level: ModifyFiles
     * @param filePayload
     * @param expiresAfterDays After how many days should the file be deleted.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    filesPost(filePayload: FilePayload, expiresAfterDays?: number, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<FileInfo>;
    filesPost(filePayload: FilePayload, expiresAfterDays?: number, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<FileInfo>>;
    filesPost(filePayload: FilePayload, expiresAfterDays?: number, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<FileInfo>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilesService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FilesService>;
}
